@@ -13,7 +13,9 @@ from .__about__ import (
 )
 
 from .sde import main
-from .sde import edit_file, read_file
+# We intentially import for export here, so it is ok to silence DeepSource test
+# skipcq: PY-W2000
+from .sde import edit_file, normalize_val, read_file
 
 # https://realpython.com/python-logging-source-code/#library-vs-application-logging-what-is-nullhandler
 # when used as library, we default to opt-in approach, wherein a library user has to enable logging
@@ -29,3 +31,6 @@ except ImportError:
             pass
 
 logging.getLogger(__name__).addHandler(NullHandler())
+
+if __name__ == "__main__":
+    main()
